# Security Policy

## Supported versions

| Version | Supported |
| :------ | :-------- |
| 0.x | Yes |

## Reporting a vulnerability

Please do not open public issues for security vulnerabilities.

Use GitHub Security Advisories to report privately:

<https://github.com/drew-simmons/fsweep/security/advisories/new>

I will acknowledge reports as quickly as possible and follow up with status and
remediation details.
